@@ -5,17 +5,16 @@
 #
 # You should have received a copy of the license along with this
 # work.  If not, see <https://creativecommons.org/licenses/by-nc-sa/4.0/>.
+
 """
-This project try to help doing handy operations with git when 
+This project try to help doing handy operations with git when
 dealing with project versioning and tags on python project -
 at leat for project using PEP440 or SemVer standards.
 
 One requirement is to keep it compact and to not cover too much fancy features.
 This is the reason why it is one single file with nested classes.
 
-=> Design is on-purpose poorly expandable to keep the scope light.
-
-This library is maid for repository using tag as version.
+This library is made for repository that uses tags as version.
 Support for non-version tags is optional and not well tested.
 
 This module is the main project file, containing all the code.
@@ -23,34 +22,68 @@ This module is the main project file, containing all the code.
 Read the read me for more information.
 Check the unittest s for usage samples.
 
-Note: _Other Parameters_ are **kwargs
+///Note
+_Other Parameters_ are **kwargs
+///
+
+Attributes:
+    TKwargs: Kwargs type definition for type hints
 """
 
 from __future__ import annotations
 
+from typing import TYPE_CHECKING, cast, TypedDict, Literal
 import os
 import subprocess
 import re
 from copy import copy
 import logging
+from pathlib import Path
 
 from packaging.version import VERSION_PATTERN as packaging_VERSION_PATTERN
 
+if TYPE_CHECKING:
+    from typing import List, Optional, Any, Dict
+    from typing_extensions import Unpack
 
-def _exec(cmd: str, root: str | os.PathLike | None = None, raw: bool = False) -> list[str]:
-    """
-    helper function to handle system cmd execution
+    TKwargs = TypedDict(
+        "TKwargs",
+        {
+            "version_std": Optional[str],
+            "same_branch": Optional[bool],
+            "formated_output": Optional[bool],
+            "bump_type": Optional[str],
+            "bump_dev_strategy": Optional[str],
+            "merged_output": Optional[bool],
+            "ignore_unknown_tags": Optional[bool],
+            "output_format": Optional[str],
+        },
+        total=False,
+    )
+
+
+def _exec(cmd: str, root: Optional[str | os.PathLike[str]] = None, raw: bool = False) -> str | List[str]:
+    """helper function to handle system cmd execution
     Args:
         cmd: command line to be executed
         root: root directory where the command need to be executed
+        raw: return bytes if True, str if False or None
     Returns:
-        a list of command's return lines
+        a list of command's return lines or the raw output
 
     """
+    _root: Path
+    if isinstance(root, str):
+        _root = Path(root)
+    elif isinstance(root, os.PathLike):
+        _root = Path(root)
+    else:
+        _root = Path(os.getcwd())
+
     p = subprocess.run(
         cmd,
         text=True,
-        cwd=root,
+        cwd=_root,
         capture_output=True,
         check=False,
         timeout=2,
@@ -63,99 +96,74 @@ def _exec(cmd: str, root: str | os.PathLike | None = None, raw: bool = False) ->
     if int(p.returncode) < 0:
         raise gitversionhelper.unknownGITError(p.stderr)
 
-    if raw:
+    if raw is True:
         return p.stdout
     lines = p.stdout.splitlines()
     return [line.rstrip() for line in lines if line.rstrip()]
 
 
 class gitversionhelperException(Exception):
-    """
-    general Module Exception
-    """
+    """general Module Exception"""
 
 
 class gitversionhelper:  # pylint: disable=too-few-public-methods
-    """
-    main gitversionhelper class
-    """
+    """main gitversionhelper class"""
 
     class wrongArguments(gitversionhelperException):
-        """
-        wrong argument generic exception
-        """
+        """wrong argument generic exception"""
 
     class unknownGITError(gitversionhelperException):
-        """
-        unknown git error generic exception
-        """
+        """unknown git error generic exception"""
 
     class unknownGITFatalError(unknownGITError):
-        """
-        unknown fatal git error generic exception
-        """
+        """unknown fatal git error generic exception"""
 
     class repository:
-        """
-        class containing methods focusing on repository
-        """
+        """class containing methods focusing on repository"""
 
         class repositoryException(gitversionhelperException):
-            """
-            generic repository exeption
-            """
+            """generic repository exeption"""
 
         class notAGitRepository(repositoryException):
-            """
-            not a git repository exception
-            """
+            """not-a-git-repository repository exception"""
 
         class repositoryDirty(repositoryException):
-            """
-            dirty repository exception
-            """
+            """dirty-repository repository exception"""
 
         @classmethod
         def isDirty(cls) -> bool:
-            """
-            check if the repository is in dirty state
+            """check if the repository is in dirty state
             Returns:
                 True if it is dirty
             """
             return bool(_exec("git status --short"))
 
     class commit:
-        """
-        class containing methods focusing on commits
-        """
-
-        __OptDict = {"same_branch": "same_branch", "merged_output": "merged_output"}
+        """class containing methods focusing on commits"""
 
         class commitException(gitversionhelperException):
-            """
-            generic commit exception
-            """
+            """generic commit exception"""
 
         class commitNotFound(commitException):
-            """
-            tag not found exception
-            """
+            """tag not found exception"""
 
         @classmethod
-        def getMessagesSinceTag(cls, tag: str, **kwargs) -> str:
-            """
-            retrieve a commits message history from repository
-            from Latest commit to the given tag
+        def getMessagesSinceTag(cls, tag: str, **kwargs: Unpack[TKwargs]) -> str | List[str]:
+            """Retrieve a commits message history from repository.
+
+            Start from Latest found commit until the given tag.
+            Args:
+                tag: tag of the commit where search will stop
             Keyword Arguments:
-                merged_output: output one single merged string
-                same_branch(bool): force searching only in the same branch
+                kwargs/merged_output (bool): Output one single merged string
+                kwargs/same_branch (bool): Force searching only in the same branch
             Returns:
                 the commit message
             """
             current_commit_id = cls.getLast(**kwargs)
             tag_commit_id = cls.getFromTag(tag)
 
-            if (cls.__OptDict["same_branch"] in kwargs) and (kwargs[cls.__OptDict["same_branch"]] is True):
+            if ("same_branch" in kwargs) and (kwargs["same_branch"] is True):
                 commits = _exec(f"git rev-list --first-parent --ancestry-path {tag_commit_id}..{current_commit_id}")
             else:
                 commits = _exec(f"git rev-list --ancestry-path {tag_commit_id}..{current_commit_id}")
@@ -163,15 +171,13 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             for commit in commits:
                 result.append(cls.getMessage(commit))
 
-            if (cls.__OptDict["merged_output"] in kwargs) and (kwargs[cls.__OptDict["merged_output"]] is True):
-                print("JOIN")
+            if ("merged_output" in kwargs) and (kwargs["merged_output"] is True):
                 return os.linesep.join(result)
             return result
 
         @classmethod
         def getMessage(cls, commit_hash: str) -> str:
-            """
-            retrieve a commit message from repository
+            """retrieve a commit message from repository
             Args:
                 commit_hash: id of the commit
             Returns:
@@ -182,7 +188,8 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                     f'git log -z --pretty="tformat:%B%-C()" -n 1 {commit_hash}',
                     None,
                     True,
-                ).rstrip("\x00")
+                )
+                res = cast(str, res).rstrip("\x00")
             except gitversionhelper.unknownGITFatalError as _e:
                 raise cls.commitNotFound("no commit found in commit history") from _e
 
@@ -190,8 +197,7 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
 
         @classmethod
         def getFromTag(cls, tag: str) -> str:
-            """
-            retrieve a commit from repository associated to a tag
+            """retrieve a commit from repository associated to a tag
             Args:
                 tag: tag of the commit
             Returns:
@@ -206,15 +212,14 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             return res[0]
 
         @classmethod
-        def getLast(cls, **kwargs) -> str:
-            """
-            retrieve last commit from repository
+        def getLast(cls, **kwargs: Unpack[TKwargs]) -> str:
+            """retrieve last commit from repository
             Keyword Arguments:
-                same_branch(bool): force searching only in the same branch
+                kwargs/same_branch (bool): force searching only in the same branch
             Returns:
                 the commit Id
             """
-            if (cls.__OptDict["same_branch"] in kwargs) and (kwargs[cls.__OptDict["same_branch"]] is True):
+            if ("same_branch" in kwargs) and (kwargs["same_branch"] is True):
                 try:
                     res = _exec("git rev-parse HEAD")
                 except gitversionhelper.unknownGITFatalError as _e:
@@ -227,11 +232,8 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             return res[0]
 
     class tag:
-        """
-        class containing methods focusing on tags
-        """
+        """class containing methods focusing on tags"""
 
-        __OptDict = {"same_branch": "same_branch"}
         __validGitTagSort = [
             "",
             "v:refname",
@@ -243,48 +245,42 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
         ]
 
         class tagException(gitversionhelperException):
-            """
-            generic tag exception
-            """
+            """generic tag exception"""
 
         class tagNotFound(tagException):
-            """
-            tag not found exception
-            """
+            """tag-not-found tag exception"""
 
         class moreThanOneTag(tagException):
-            """
-            more than one tag exception
-            """
+            """more-than-one-tag tag exception"""
 
         @classmethod
-        def getTags(cls, sort: str = "taggerdate", **kwargs) -> list[str | None]:
-            """
-            retrieve all tags from a repository
+        def getTags(cls, Sort: str = "taggerdate", **kwargs: Unpack[TKwargs]) -> List[str]:
+            """retrieve all tags from a repository
             Args:
-                sort: sorting constraints (git format)
+                Sort: sorting constraints (git format)
+            Keyword Arguments:
+                kwargs/same_branch (bool): force searching only in the same branch
             Returns:
                 the tags list
             """
 
-            if sort not in cls.__validGitTagSort:
-                raise gitversionhelper.wrongArguments("sort option not in allowed list")
+            if Sort not in cls.__validGitTagSort:
+                raise gitversionhelper.wrongArguments("Sort option not in allowed list")
 
-            if (cls.__OptDict["same_branch"] in kwargs) and (kwargs[cls.__OptDict["same_branch"]] is True):
+            if ("same_branch" in kwargs) and (kwargs["same_branch"] is True):
                 currentBranch = _exec("git rev-parse --abbrev-ref HEAD")
-                return list(reversed(_exec(f"git tag --merged {currentBranch[0]} --sort={sort}")))
-            return list(reversed(_exec(f"git tag -l --sort={sort}")))
+                return list(reversed(_exec(f"git tag --merged {currentBranch[0]} --sort={Sort}")))
+            return list(reversed(_exec(f"git tag -l --sort={Sort}")))
 
         @classmethod
-        def getLastTag(cls, **kwargs) -> str | None:
-            """
-            retrieve the Latest tag from a repository
+        def getLastTag(cls, **kwargs: Unpack[TKwargs]) -> str:
+            """retrieve the Latest tag from a repository
             Keyword Arguments:
-                same_branch(bool): force searching only in the same branch
+                kwargs/same_branch (bool): force searching only in the same branch
             Returns:
                 the tag
             """
-            if (cls.__OptDict["same_branch"] in kwargs) and (kwargs[cls.__OptDict["same_branch"]] is True):
+            if ("same_branch" in kwargs) and (kwargs["same_branch"] is True):
                 res = _exec("git describe --tags --first-parent --abbrev=0")
             else:
                 res = _exec("git rev-list --tags --date-order --max-count=1")
@@ -298,13 +294,12 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             return res[0]
 
         @classmethod
-        def getDistanceFromTag(cls, tag: str = None, **kwargs) -> int:
-            """
-            retrieve the distance between Latest commit and tag in the repository
+        def getDistanceFromTag(cls, tag: Optional[str] = None, **kwargs: Unpack[TKwargs]) -> int:
+            """retrieve the distance between Latest commit and tag in the repository
             Arguments:
                 tag: reference tag, if None the most recent one will be used
             Keyword Arguments:
-                same_branch(bool): force searching only in the same branch
+                kwargs/same_branch (bool): force searching only in the same branch
             Returns:
                 the tag
             """
@@ -313,18 +308,13 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             return int(_exec(f"git rev-list {tag}..HEAD --count")[0])
 
     class version:
-        """
-        class containing methods focusing on versions
-        """
+        """class containing methods focusing on versions"""
 
-        __OptDict = {
-            "version_std": "version_std",
-            "formated_output": "formated_output",
-            "output_format": "output_format",
-            "ignore_unknown_tags": "ignore_unknown_tags",
-        }
         DefaultInputFormat = "Auto"
-        VersionStds = {
+
+        TVersionStds = TypedDict("TVersionStds", {"regex": str, "regex_preversion_num": str, "regex_build_num": str}, total=False)
+
+        VersionStds: dict[str, TVersionStds] = {
             "SemVer": {
                 "regex": r"^(?P<major>0|[1-9]\d*)\.(?P<minor>0|[1-9]\d*)\.(?P<patch>0|[1-9]\d*)"
                 r"(?:-(?P<prerelease>(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)"
@@ -333,41 +323,32 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                 "regex_preversion_num": r"(?:\.)(?P<num>(?:\d+(?!\w))+)",
                 "regex_build_num": r"(?:\.)(?P<num>(?:\d+(?!\w))+)",
             },
-            "PEP440": {"regex": packaging_VERSION_PATTERN, "Auto": None},
+            "PEP440": {"regex": packaging_VERSION_PATTERN},
         }
         __versionReseted = False
 
         class versionException(gitversionhelperException):
-            """
-            generic version exception
-            """
+            """generic version exception"""
 
         class noValidVersion(versionException):
-            """
-            no valid version found exception
-            """
+            """no valid version found exception"""
 
         class PreAndPostVersionUnsupported(versionException):
-            """
-            pre and post release can not be present at the same time
-            """
+            """pre and post release can not be present at the same time"""
 
         class MetaVersion:
-            """
-            generic version object
-            """
+            """generic version object"""
 
-            __OptDict = {
-                "bump_type": "bump_type",
-                "bump_dev_strategy": "bump_dev_strategy",
-                "formated_output": "formated_output",
-            }
-            DefaultBumpType = "patch"
-            BumpTypes = ["major", "minor", "patch", "dev"]
-            DefaultBumpDevStrategy = "post"
-            BumpDevStrategys = ["post", "pre-patch", "pre-minor", "pre-major"]
+            TBumpTypes = Literal["major", "minor", "patch", "dev"]
+            DefaultBumpType: TBumpTypes = "patch"
+            BumpTypes: set[TBumpTypes] = {"major", "minor", "patch", "dev"}
 
-            version_std: str = "None"
+            TBumpDevStrategies = Literal["post", "pre-patch", "pre-minor", "pre-major"]
+            DefaultBumpDevStrategy: TBumpDevStrategies = "post"
+            BumpDevStrategies: set[TBumpDevStrategies] = {"post", "pre-patch", "pre-minor", "pre-major"}
+
+            TVersionStd = Literal["Auto", "PEP440", "SemVer"]
+            version_std: TVersionStd = "Auto"
             major: int = 0
             minor: int = 1
             patch: int = 0
@@ -377,13 +358,13 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
 
             def __init__(
                 self,
-                version_std,
-                major=0,
-                minor=1,
-                patch=0,
-                pre_count=0,
-                post_count=0,
-                raw="0.1.0",
+                version_std: TVersionStd = "Auto",
+                major: int = 0,
+                minor: int = 1,
+                patch: int = 0,
+                pre_count: int = 0,
+                post_count: int = 0,
+                raw: str = "0.1.0",
             ):  # pylint: disable=R0913
                 self.version_std = version_std
                 self.major = major
@@ -394,50 +375,55 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                 self.raw = raw
 
             @classmethod
-            def _getBumpDevStrategy(cls, **kwargs) -> str:
-                """
-                get selected bump_dev_strategy
+            def _getBumpDevStrategy(cls, **kwargs: Unpack[TKwargs]) -> str:
+                """get selected bump_dev_strategy
                 Keyword Arguments:
-                    bump_dev_strategy(str): the given bump_dev_strategy (can be None)
+                    kwargs/bump_dev_strategy (str): the given bump_dev_strategy (can be None)
                 Returns:
                     Kwargs given bump_dev_strategy or the default one.
                 """
-                BumpDevStrategy = cls.DefaultBumpDevStrategy
-                if cls.__OptDict["bump_dev_strategy"] in kwargs:
-                    if kwargs[cls.__OptDict["bump_dev_strategy"]] in cls.BumpDevStrategys:
-                        BumpDevStrategy = kwargs[cls.__OptDict["bump_dev_strategy"]]
+                BumpDevStrategy: str = cls.DefaultBumpDevStrategy
+
+                if kwargs and ("bump_dev_strategy" in kwargs):
+                    if kwargs["bump_dev_strategy"] in cls.BumpDevStrategies:
+                        BumpDevStrategy = kwargs["bump_dev_strategy"]
                     else:
-                        raise gitversionhelper.wrongArguments(f"invalid {cls.__OptDict['bump_type']} requested")
+                        raise gitversionhelper.wrongArguments(f"invalid {'bump_type'} requested")
                 return BumpDevStrategy
 
             @classmethod
-            def _getBumpType(cls, **kwargs) -> str:
-                """
-                get selected bump_type
+            def _getBumpType(cls, **kwargs: Unpack[TKwargs]) -> str:
+                """get selected bump_type
                 Keyword Arguments:
-                    bump_type(str): the given bump_type (can be None)
+                    kwargs/bump_type (str): the given bump_type (can be None)
                 Returns:
                     Kwargs given bump_type or the default one.
                 """
-                BumpType = cls.DefaultBumpType
-                if cls.__OptDict["bump_type"] in kwargs:
-                    if kwargs[cls.__OptDict["bump_type"]] in cls.BumpTypes:
-                        BumpType = kwargs[cls.__OptDict["bump_type"]]
+                BumpType: str = cls.DefaultBumpType
+                if "bump_type" in kwargs:
+                    if kwargs["bump_type"] in cls.BumpTypes:
+                        BumpType = kwargs["bump_type"]
                     else:
-                        raise gitversionhelper.wrongArguments(f"invalid {cls.__OptDict['bump_type']} requested")
+                        raise gitversionhelper.wrongArguments(f"invalid {'bump_type'} requested")
                 return BumpType
 
-            def bump(self, amount: int = 1, **kwargs) -> gitversionhelper.version.MetaVersion | str:  # pylint: disable=R0912
-                """
-                bump the version to the next one
+            def bump(  # pylint: disable=R1260,R0912
+                self, amount: int = 1, **kwargs: Unpack[TKwargs]
+            ) -> gitversionhelper.version.MetaVersion | str:
+                """bump the version to the next one
+                Args:
+                    amount: number of revision to bump
                 Keyword Arguments:
-                    bump_type(str): the given bump_type (can be None)
-                    bump_dev_strategy(str): the given bump_dev_strategy (can be None)
+                    kwargs/bump_type (str): the given bump_type (can be None)
+                    kwargs/bump_dev_strategy (str): the given bump_dev_strategy (can be None)
                 Returns:
                     the bumped version
                 """
-                BumpType = self._getBumpType(**kwargs)
+
+                BumpType: str = self._getBumpType(**kwargs)
+
                 BumpDevStrategy = self._getBumpDevStrategy(**kwargs)
+
                 _v = copy(self)
 
                 if BumpType == "dev":
@@ -473,88 +459,97 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                         _v.patch = _v.patch + amount
                     _v.pre_count = 0
                     _v.post_count = 0
+
                 _v.raw = _v.doFormatVersion(**kwargs)
 
-                if (self.__OptDict["formated_output"] in kwargs) and (kwargs[self.__OptDict["formated_output"]] is True):
+                if ("formated_output" in kwargs) and (kwargs["formated_output"] is True):
                     return _v.doFormatVersion(**kwargs)
                 return _v
 
-            def doFormatVersion(self, **kwargs) -> str:
-                """
-                output a formated version string
+            def doFormatVersion(self, **kwargs: Unpack[TKwargs]) -> str:
+                """output a formated version string
                 Keyword Arguments:
-                    output_format: output format to render ("Auto" or "PEP440" or "SemVer")
+                    kwargs/output_format: output format to render ("Auto" or "PEP440" or "SemVer")
                 Returns:
                     formated version string
                 """
                 return gitversionhelper.version.doFormatVersion(self, **kwargs)
 
         @classmethod
-        def _getVersionStd(cls, **kwargs) -> str:
-            """
-            get selected version_std
+        def _getVersionStd(cls, **kwargs: Unpack[TKwargs]) -> gitversionhelper.version.MetaVersion.TVersionStd:
+            """get selected version_std
             Keyword Arguments:
-                version_std(str): the given version_std (can be None)
+                kwargs/version_std (str): the given version_std (can be None)
             Returns:
                 Kwargs given version_std or the default one.
             """
-            VersionStd = cls.DefaultInputFormat
-            if cls.__OptDict["version_std"] in kwargs:
-                if kwargs[cls.__OptDict["version_std"]] in cls.VersionStds:
-                    VersionStd = kwargs[cls.__OptDict["version_std"]]
+            VersionStd: str = cls.DefaultInputFormat
+            if "version_std" in kwargs:
+                if kwargs["version_std"] in cls.VersionStds:
+                    VersionStd = kwargs["version_std"]
                 else:
-                    raise gitversionhelper.wrongArguments(f"invalid {cls.__OptDict['version_std']} requested")
-            return VersionStd
+                    raise gitversionhelper.wrongArguments(f"invalid {'version_std'} requested")
+            return cast(gitversionhelper.version.MetaVersion.TVersionStd, VersionStd)
 
         @classmethod
-        def getCurrentVersion(cls, **kwargs) -> MetaVersion | str:
-            """
-            get the current version or bump depending of repository state
+        def getCurrentVersion(cls, **kwargs: Unpack[TKwargs]) -> gitversionhelper.version.MetaVersion | str:
+            """get the current version or bump depending of repository state.
             Keyword Arguments:
-                version_std(str): the given version_std (can be None)
-                same_branch(bool): force searching only in the same branch
-                formated_output(bool) : output a formated version string
-                bump_type(str): the given bump_type (can be None)
-                bump_dev_strategy(str): the given bump_dev_strategy (can be None)
+                kwargs/version_std (str): the given version_std (can be None)
+                kwargs/same_branch (bool): force searching only in the same branch
+                kwargs/formated_output (bool): output a formated version string
+                kwargs/bump_type (str): the given bump_type (can be None)
+                kwargs/bump_dev_strategy (str): the given bump_dev_strategy (can be None)
+                kwargs/output_format (str): output format to render ("Auto" or "PEP440" or "SemVer")
             Returns:
                 the last version
             """
             if gitversionhelper.repository.isDirty() is not False:
                 raise gitversionhelper.repository.repositoryDirty("The repository is dirty and a current version can not be generated.")
+
             saved_kwargs = copy(kwargs)
             if "formated_output" in kwargs:
                 del saved_kwargs["formated_output"]
 
-            _v = cls.getLastVersion(**saved_kwargs)
+            _v = cast(gitversionhelper.version.MetaVersion, cls.getLastVersion(**saved_kwargs))
 
             if not cls.__versionReseted:
-                amount = gitversionhelper.tag.getDistanceFromTag(_v.raw, **kwargs)
-                _v = _v.bump(amount, **saved_kwargs)
+                amount = gitversionhelper.tag.getDistanceFromTag(_v.raw, **saved_kwargs)
+                _v = cast(gitversionhelper.version.MetaVersion, _v.bump(amount, **saved_kwargs))
 
-            if (cls.__OptDict["formated_output"] in kwargs) and (kwargs[cls.__OptDict["formated_output"]] is True):
+            if ("formated_output" in kwargs) and (kwargs["formated_output"] is True):
                 return _v.doFormatVersion(**kwargs)
             return _v
 
         @classmethod
-        def getCurrentFormatedVersion(cls, **kwargs) -> str:
-            """
-            Same as getCurrentVersion() with formated_output kwarg activated
-            """
-            kwargs["formated_output"] = True
-            return cls.getCurrentVersion(**kwargs)
-
-        @classmethod
-        def _parseTag(cls, tag, **kwargs):  # pylint: disable=R0914, R0912, R0915
-            """get the last version from tags
-            Arguments:
-                tag: the tag to be parsed
+        def getCurrentFormatedVersion(cls, **kwargs: Unpack[TKwargs]) -> str:
+            """same as getCurrentVersion() with formated_output kwarg forced activated.
             Keyword Arguments:
-                version_std(str): the given version_std (can be None)
-                ignore_unknown_tags(bool): skip tags with not decoded versions (default to False)
+                kwargs/version_std (str): the given version_std (can be None)
+                kwargs/same_branch (bool): force searching only in the same branch
+                kwargs/bump_type (str): the given bump_type (can be None)
+                kwargs/bump_dev_strategy (str): the given bump_dev_strategy (can be None)
+                kwargs/output_format (str): output format to render ("Auto" or "PEP440" or "SemVer")
             Returns:
                 the last version
             """
-            VersionStd = cls._getVersionStd(**kwargs)
+            kwargs["formated_output"] = True
+            return cast(str, cls.getCurrentVersion(**kwargs))
+
+        @classmethod
+        def _parseTag(  # pylint: disable=R1260,R0914,R0912,R0915
+            cls, tag: str, **kwargs: Unpack[TKwargs]
+        ) -> gitversionhelper.version.MetaVersion:
+            """get version from tags.
+            Arguments:
+                tag: the tag to be parsed
+            Keyword Arguments:
+                kwargs/version_std (str): the given version_std (can be None)
+            Returns:
+                MetaVersion object
+            """
+            _m: Optional[re.Match[str]]
+            VersionStd: gitversionhelper.version.MetaVersion.TVersionStd = cls._getVersionStd(**kwargs)
             bAutoVersionStd = False
             if VersionStd == "Auto":
                 bAutoVersionStd = True
@@ -565,14 +560,12 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                     re.VERBOSE | re.IGNORECASE,
                 )
                 _m = re.match(_r, tag)
-                if not _m:
+                if _m is None:
                     pass
                 else:
-                    major, minor, patch = (
-                        int(_m.group("major")),
-                        int(_m.group("minor")),
-                        int(_m.group("patch")),
-                    )
+                    major = int(_m.group("major"))
+                    minor = int(_m.group("minor"))
+                    patch = int(_m.group("patch"))
 
                     pre_count = 0
                     if _pre := _m.group("prerelease"):
@@ -596,19 +589,25 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                     re.VERBOSE | re.IGNORECASE,
                 )
                 _m = re.match(_r, tag)
-                if not _m:
+                if _m is None:
                     pass
                 else:
-                    ver = _m.group("release").split(".")
-                    ver += ["0"] * (3 - len(ver))
-                    ver[0] = int(ver[0])
-                    ver[1] = int(ver[1])
-                    ver[2] = int(ver[2])
-                    major, minor, patch = tuple(ver)
-                    pre_count = int(_m.group("pre_n")) if _m.group("pre_n") else 0
-                    post_count = int(_m.group("post_n2")) if _m.group("post_n2") else 0
-                    bFound = True
-                    VersionStd = "PEP440"
+                    res: str = _m.group("release")
+                    if isinstance(res, str):
+
+                        ver = res.split(".")
+                        ver += ["0"] * (3 - len(ver))
+
+                        ver_int: List[int] = [0, 0, 0]
+                        ver_int[0] = int(ver[0])
+                        ver_int[1] = int(ver[1])
+                        ver_int[2] = int(ver[2])
+                        major, minor, patch = tuple(ver_int)
+
+                        pre_count = int(_m.group("pre_n")) if _m.group("pre_n") else 0
+                        post_count = int(_m.group("post_n2")) if _m.group("post_n2") else 0
+                        bFound = True
+                        VersionStd = "PEP440"
 
             if not bFound:
                 raise gitversionhelper.version.noValidVersion("no valid version found in tags")
@@ -618,30 +617,30 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             return cls.MetaVersion(VersionStd, major, minor, patch, pre_count, post_count, tag)
 
         @classmethod
-        def getLastVersion(cls, **kwargs) -> MetaVersion | str:  # pylint: disable=R0914, R0912, R0915
+        def getLastVersion(cls, **kwargs: Unpack[TKwargs]) -> gitversionhelper.version.MetaVersion | str:  # pylint: disable=R1260
             """get the last version from tags
             Keyword Arguments:
-                version_std(str): the given version_std (can be None)
-                same_branch(bool): force searching only in the same branch
-                formated_output(bool) : output a formated version string
-                ignore_unknown_tags(bool): skip tags with not decoded versions (default to False)
+                kwargs/version_std (str): the given version_std (can be None)
+                kwargs/same_branch (bool): force searching only in the same branch
+                kwargs/formated_output (bool): output a formated version string
+                kwargs/ignore_unknown_tags (bool): skip tags with not decoded versions (default to False)
             Returns:
-                the last version
+                the last version in MetaVersion object or string
             """
-            lastTag = cls.MetaVersion.raw
+            lastTag: str = cls.MetaVersion.raw
             cls.__versionReseted = False
             try:
-                lastTag = gitversionhelper.tag.getLastTag(**kwargs)
+                lastTag = cast(str, gitversionhelper.tag.getLastTag(**kwargs))
             except gitversionhelper.tag.tagNotFound:
                 logging.warning("tag not found, reseting versionning")
                 cls.__versionReseted = True
 
-            _v = None
+            _v: Optional[gitversionhelper.version.MetaVersion] = None
             try:
                 _v = cls._parseTag(lastTag, **kwargs)
             except gitversionhelper.version.noValidVersion as _ex:
-                if (cls.__OptDict["ignore_unknown_tags"] in kwargs) and (kwargs[cls.__OptDict["ignore_unknown_tags"]] is True):
-                    tags = gitversionhelper.tag.getTags(sort="taggerdate", **kwargs)
+                if ("ignore_unknown_tags" in kwargs) and (kwargs["ignore_unknown_tags"] is True):
+                    tags = gitversionhelper.tag.getTags(Sort="taggerdate", **kwargs)
                     _v = None
                     for _tag in tags:
                         try:
@@ -652,16 +651,15 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                 if _v is None:
                     raise gitversionhelper.version.noValidVersion() from _ex
 
-            if (cls.__OptDict["formated_output"] in kwargs) and (kwargs[cls.__OptDict["formated_output"]] is True):
+            if ("formated_output" in kwargs) and (kwargs["formated_output"] is True):
                 return _v.doFormatVersion(**kwargs)
             return _v
 
         @classmethod
-        def doFormatVersion(cls, inputversion: MetaVersion, **kwargs) -> str:
-            """
-            output a formated version string
+        def doFormatVersion(cls, inputversion: MetaVersion, **kwargs: Unpack[TKwargs]) -> str:
+            """output a formated version string from a MetaVersion object
             Keyword Arguments:
-                output_format: output format to render ("Auto" or "PEP440" or "SemVer")
+                kwargs/output_format (str): output format to render ("Auto" or "PEP440" or "SemVer")
             Args:
                 inputversion: version to be rendered
             Returns:
@@ -672,15 +670,13 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             if VersionStd == "Auto":
                 VersionStd = inputversion.version_std
 
-            OutputFormat = None
             revpattern = ""
             revcount = ""
             post_count = inputversion.post_count
             pre_count = inputversion.pre_count
             patch = inputversion.patch
 
-            if cls.__OptDict["output_format"] in kwargs:
-                OutputFormat = kwargs[cls.__OptDict["output_format"]]
+            OutputFormat = kwargs.get("output_format")
 
             if OutputFormat is None:
                 OutputFormat = "{major}.{minor}.{patch}{revpattern}{revcount}"
