@@ -730,9 +730,9 @@ class Test_gitversionhelper(unittest.TestCase):
         with self.assertRaises(pygitversionhelper.gitversionhelper.version.PreAndPostVersionUnsupported):
             pygitversionhelper.gitversionhelper.version._parseTag("0.0.1.pre1.post1")
 
-    def test_defect__git__wrongargument_sortargs(self):
+    def test_defect__git__wrongargument_Sortargs(self):
         with self.assertRaises(pygitversionhelper.gitversionhelper.wrongArguments):
-            pygitversionhelper.gitversionhelper.tag.getTags(sort="toto")
+            pygitversionhelper.gitversionhelper.tag.getTags(Sort="toto")
 
     def test_defect__git__notagfound(self):
         with open("demofile.txt", "w+t") as tmpFile:
